/**
 * @file	ccsv.h
 * @brief	CSV data operation class
 * @date	2004.02.14
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *    CSV data operation class.
 */

#ifndef CCSV_H_INCLUDED
#define CCSV_H_INCLUDED

#include <Coconut/coconut-sysdep.h>
#include <Coconut/clist.h>

/**
 * @brief	CCsv class operates the information for 
 *		command line options.
 * @par Description
 *   CCsv class operates the information for command line options.
 */
@interface CCsv : NSObject 
{
	/** List of list for colmuns. */
	CList *		row_list ;
}

  /**
   * @brief	Parse text data and make CSV data.
   * @return	Generated CSV file.
   *		If some error occured, this pointer will be nil.
   * @param	str Input text data.
   * @param	withesc Set true to use back-slash code to escape
   *		sepatator (command).
   * @par Description
   *   Parse CSV file and make CSV data.
   *   If you want use '\' to escape comma, set true to 
   *   '<code>withesc</code>' parameter.
   */
  + parse: (NSString *) str withEscape: (BOOL) withesc ;

  /**
   * @brief	Initialize CCsv instance 
   * @return	Initialized object.
   * @par Description
   *   Initialize CCsv instance.
   */
  - init ;

  /**
   * @brief	Release the content of CSV data.
   * @par Description
   *   Release the content of CSV data.
   */
  - (void) dealloc ;

  /**
   * @brief	Parse text data and make CSV data.
   * @return	Generated CSV file.
   *		If some error occured, this pointer will be nil.
   * @param	str Input text data.
   * @par Description
   *   Parse CSV file and make CSV data.
   *   If you want use '\' to escape comma, set true to 
   *   '<code>withesc</code>' parameter.
   * @param	withesc Set true to use back-slash code to escape
   *		sepatator (command).
   */
  - (int) parse: (NSString *) str withEscape: (BOOL) withesc ;

  /**
   * @brief	Get number of rows in the CSV data.
   * @return	Number of rows.
   * @par Description
   *   Get number of rows in the CSV data.
   */
  - (uint_t) rowNum ;

  /**
   * @brief	Get list of rows in CSV data.
   * @return	List of rows.
   * @par Description
   *    Get list of rows in CSV data.
   *    The item of list cointains list (#CList) of colmuns.
   *    The item of colmun is string (#NSString).
   */
  - (CList *) rowList ;

  /**
   * @brief	Print the content of CSV data.
   * @param	outfp Output stream.
   * @par Description
   *   Print the content of CSV data.
   */
  - (void) print: (FILE *) outfp ;
@end

#endif /* CCSV_H_INCLUDED */

