/**
 * @file	cstrutils.h
 * @brief	Utility methods to operate #NSString objects.
 * @date	2004.02.14
 * @author	Steel Wheels Project
 * @par Copyright
 *   Copyright (C) 2004 Steel Wheels Project.
 *   All right reserved.
 * @par Description
 *    Utility methods to operate #NSString objects.
 */

#ifndef CSTRUTILS_H_INCLUDED
#define CSTRUTILS_H_INCLUDED

#include <Coconut/coconut-sysdep.h>

/**
 * @brief	Utility methods for NSString data.
 * @par Description
 *   Utility methods for NSString data.
 */
@interface CStrUtils : NSObject 
{
}
  /**
   * @brief	Check the string contains only spaces or not.
   * @return	True when the source string contains spaces only.
   * @param	src Source string. If this is nil, the method returns True.
   * @par Description
   *   Check the string contains only spaces or not.
   */
  + (BOOL) isBlankString: (NSString *) src ;

  /**
   * @brief	Separate string by character.
   * @param	src Source string.
   * @param	c Separator character.
   * @param	doesc If this is true, the separator character follows 
   *		back slash is not recognized as separator.
   * @par Description
   *   Separate string by character.
   *   If <code>doesc</code> flag is true, 
   *   the separator character follows back slash is not recognized 
   *   as separator.
   */
  + (NSMutableArray *) separate: (NSString *) src byCharacter: (unichar_t) c
    withEscape: (BOOL) doesc ;

  /**
   * @brief	Replace target string by given substring.
   * @param	dst Destination mutable string.
   * @param	targ Substring to be replaced.
   * @param	substr Substring to replace.
   * @param	dorec Replace all strings or not.
   * @par Description
   *    Replace target string by given substring.
   */
  + (void) replaceString: (NSMutableString *) dst target: (NSString *) targ
    by: (NSString *) substr doRecursive: (BOOL) dorec ;

@end

#endif /* CSTRUTILS_H_INCLUDED */

